fn parse_control_point_abs(
iter: &mut Peekable<Cloned<Iter<'_, u8>>>,
) -> Result<ControlPoint<SVGPathPosition, CSSFloat>, ()>Expand description
Parse a pair of values that describe the absolutely positioned curve control point.
fn parse_control_point_abs(
iter: &mut Peekable<Cloned<Iter<'_, u8>>>,
) -> Result<ControlPoint<SVGPathPosition, CSSFloat>, ()>Parse a pair of values that describe the absolutely positioned curve control point.